# 20240122_v0.10.4_prod5_trans80

20 degrees for performance study

lstmcpipe_generate_config PathConfigProd5Trans80 --prod_id 20240122_v0.10.4_prod5_trans80

Contact : Mathieu de Bony, Léo Le Moigne, David Sanchez


